
# dcodelib
 
---
Collection of various serialization methods with cli

---
## Quickstart

```bash
# From pypi
pip install --upgrade dcodelib

# From source
pip install --upgrade git+https://github.com/trisongz/dcodelib
```

## Usage

```bash
dcode b64 decode ...

decode bgz encode ...

```

---

## Libraries & Dependencies

- `Python 3.6`

- `pylogz`

- `boltons`

- `pyyaml`

---

This Python Library has been autogenerated with [pylibup](https://github.com/trisongz/pylibup).
